Conducting Wall Mode
====================

Simplified model for instability driven by sheath boundary condition
and electron temperature gradient in a straight magnetic field.

Created by B.Friedman to go with his [slides for a hands-on
exercise](https://bout2013.llnl.gov/pdf/2011/talks/Friedman_lapda_afternoon.pdf)
at the 2013 BOUT++ workshop.

